'A reference to the Phidget22.NET.dll must be added to new projects in VB.Net 
'From the "Project" menu select "Add Reference" 
'From the "Add Reference" window select the "Browse" tab 
'Browse to the directory you installed the Phidgets library to 
'The default is "C:\Program Files\Phidgets" 
'Select "Phidget22.NET.dll" and click "OK" 
'To view objects that have been added, select the "View" menu 
'Select "Object Browser" 
'Then expand the Phidget22.NET.dll item 



Imports Phidget22
Imports Phidget22.Events

Public Class Form1
    Dim WithEvents device As Phidget22.Gyroscope
    Dim open As ExampleUtils.ExampleUtils.CommandLineOpen
    Dim errorBox As ErrorEventBox

    Dim lastMsCount As Double() = {0, 0, 0}
    Dim lastMsCountGood As Boolean() = {False, False, False}
    Dim gyroHeading As Double() = {0, 0, 0} 'degrees

    Public Sub New()
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Public Sub New(ByVal commandLine As String())
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        open.commandLine = commandLine
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        errorBox = New ErrorEventBox(Me)
        device = New Phidget22.Gyroscope()

        open.openCmdLine(device)
    End Sub

    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        If device.Attached Then
            device.Close()
        End If
    End Sub

    Private Sub device_Attach(ByVal sender As Object, ByVal e As Phidget22.Events.AttachEventArgs) Handles device.Attach
        Dim attachedDevice As Phidget22.Gyroscope = CType(sender, Phidget22.Gyroscope)
        PhidgetInfoBox1.FillPhidgetInfo(attachedDevice)

        Try
            dataIntervalTrk.Unit = "ms"
            dataIntervalTrk.minTxt = attachedDevice.MinDataInterval.ToString()
            dataIntervalTrk.Minimum = attachedDevice.MinDataInterval
            dataIntervalTrk.maxTxt = attachedDevice.MaxDataInterval.ToString()
            dataIntervalTrk.Maximum = attachedDevice.MaxDataInterval
            dataIntervalTrk.Value = attachedDevice.DataInterval
            dataIntervalTrk.trkText = attachedDevice.DataInterval.ToString()
        Catch ex As Exception
            errorBox.addMessage("Error setting the data interval: " + ex.Message)
        End Try

        settingsBox.Visible = True
        outputBox.Visible = True
        gaugeBox.Visible = True
    End Sub

    Private Sub device_Detach(ByVal sender As Object, ByVal e As Phidget22.Events.DetachEventArgs) Handles device.Detach
        PhidgetInfoBox1.Clear()

        settingsBox.Visible = False
        outputBox.Visible = False
        gaugeBox.Visible = False
    End Sub

    Private Sub device_Error(ByVal sender As Object, ByVal e As Phidget22.Events.ErrorEventArgs) Handles device.Error
        errorBox.addMessage(e.Description)
    End Sub

    Private Sub device_AngularRateChange(ByVal sender As Object, ByVal e As Phidget22.Events.GyroscopeAngularRateUpdateEventArgs) Handles device.AngularRateUpdate
        Try 'display the angular rates and calculate the angular positions
            calculateGyroHeading(e, 0)
            calculateGyroHeading(e, 1)
            calculateGyroHeading(e, 2)

            xRatetxt.Text = e.AngularRate(0).ToString() + " /s"
            yRatetxt.Text = e.AngularRate(1).ToString() + " /s"
            zRatetxt.Text = e.AngularRate(2).ToString() + " /s"

            xPosition.Value = CType(gyroHeading(0), Double)
            yPosition.Value = CType(gyroHeading(1), Double)
            zPosition.Value = CType(gyroHeading(2), Double)
        Catch ex As Exception
            errorBox.addMessage("Error reading output: " + ex.Message)
        End Try
    End Sub

    Private Sub calculateGyroHeading(ByVal data As Phidget22.Events.GyroscopeAngularRateUpdateEventArgs, ByVal index As Integer)
        Dim gyro As Double = data.AngularRate(index)

        If (lastMsCountGood(index)) Then
            Dim timechange As Double = data.Timestamp - lastMsCount(index) 'in ms
            Dim timeChangeSeconds As Double = CType(timechange, Double) / 1000.0

            gyroHeading(index) += timeChangeSeconds * gyro

            'ensure proper wrap around
            If (gyroHeading(index) > 180) Then
                gyroHeading(index) -= 360
            ElseIf (gyroHeading(index) < -180) Then
                gyroHeading(index) += 360
            End If
        End If

        lastMsCount(index) = data.Timestamp
        lastMsCountGood(index) = True
    End Sub

    Private Sub dataIntervalTrk_Scroll(sender As Object, e As EventArgs) Handles dataIntervalTrk.LogScroll
        If (MouseButtons = MouseButtons.Left) Then
            Try
                device.DataInterval = CType(dataIntervalTrk.Value, Integer)
            Catch ex As Exception
                errorBox.addMessage("Error setting data interval: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub dataIntervalTrk_LogMouseUp(sender As Object, e As EventArgs) Handles dataIntervalTrk.LogMouseUp
        Try
            device.DataInterval = CType(dataIntervalTrk.Value, Integer)
        Catch ex As Exception
            errorBox.addMessage("Error setting data interval: " + ex.Message)
        End Try
    End Sub

    Private Sub zeroBtn_Click(sender As Object, e As EventArgs) Handles zeroBtn.Click
        'zero the gyroscope positions
        device.Zero()
        System.Threading.Thread.Sleep(100)
        gyroHeading(0) = 0
        gyroHeading(1) = 0
        gyroHeading(2) = 0
    End Sub
End Class



